@@ -5,8 +5,8 @@ class CommandPSD6(Command):
     def __init__(self, type):
         super().__init__(type)
 
-    def hSetSyringeMode(self, mode: int):
-        cmd = super().hSetSyringeMode(mode)
+    def setSyringeMode(self, mode: int):
+        cmd = super().setSyringeMode(mode)
         if mode == 0 or mode == 1:
             self.resolution_mode = mode
         print("set syringe mode for PSD 6")
